Documentation
¶
Index ¶
Constants ¶
const ( MissingAuthHeaderMessage = "missing authorization header" InvalidAuthHeaderMessage = "invalid authorization header, must begin with 'Bearer '" InvalidTokenFormatMessage = "invalid token format in authorization header, must be JWT" NoTrustedKeyMessage = "A valid JWT was found, however it was not signed by any trusted key" ExpiredJWTMessage = "JWT expired at %s" FailedToUnmarshalMessage = "failed to unmarshal JWT claim, please check the token format" InvalidSignatureMessage = "invalid signature in JWT, please check the token format" VerifiedJWTHeader = "X-Verified-JWT" )
Variables ¶
var ValidSignatureAlgorithms = []jose.SignatureAlgorithm{jose.EdDSA}
Functions ¶
This section is empty.
Types ¶
type AuthFunc ¶
func JWKSAuthFunc ¶
Click to show internal directories.
Click to hide internal directories.